/**
 * Create document that is used to store temporary properties information when the app pauses.
 * Create document as plain text.
 * This will be deleted upon script completion.
 *
 * @param {string} destId - the ID of the destination folder
 * @return {Object} metadata for the properties document, or error on fail.
 */
function createPropertiesDocument(destId) {
  try {
    var propertiesDoc = DriveApp.getFolderById(destId).createFile(
      'DO NOT DELETE OR MODIFY - will be deleted after copying completes',
      '',
      MimeType.PLAIN_TEXT
    );
    propertiesDoc.setDescription(
      'This document will be deleted after the folder copy is complete.  It is only used to store properties necessary to complete the copying procedure'
    );
    return propertiesDoc.getId();
  } catch (err) {
    return err.message;
  }
}
